SwitchCase class

Constructors

SwitchCase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

altComponentSC<TOptionType, TValue>(String selectedOption, Map<String, Widget> branches, [Widget? defaultValue]) → Widget
componentWidthSC<TOptionType, TValue>(String selectedOption, Map<String, double> branches, [double? defaultValue]) → double
labelComponentFontSizeSC<TOptionType, TValue>(String selectedOption, Map<String, double> branches, [double? defaultValue]) → double
labelComponentWidthSC<TOptionType, TValue>(String selectedOption, Map<String, double> branches, [double? defaultValue]) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited